@@ -8,6 +8,6 @@ fi
 chown root.utmp var/run/utmp var/log/wtmp
 chmod 664 var/run/utmp var/log/wtmp
 ( cd usr/lib ; rm -rf libutempter.so.0 )
-( cd usr/lib ; ln -sf libutempter.so.0.5.2 libutempter.so.0 )
+( cd usr/lib ; ln -sf libutempter.so.1.1.1 libutempter.so.0 )
 ( cd usr/lib ; rm -rf libutempter.so )
-( cd usr/lib ; ln -sf libutempter.so.0.5.2 libutempter.so )
+( cd usr/lib ; ln -sf libutempter.so.0 libutempter.so )
